import java.lang.annotation.Annotation;
import java.lang.annotation.ElementType;
import java.lang.annotation.Target;
import java.lang.reflect.AnnotatedElement;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;

import jp.gr.java_conf.skrb.annotation.Log;
import jp.gr.java_conf.skrb.annotation.LogLevel;

public class LogReader {
    public LogReader() {}

    public void readAnnotation(String classname) {
        try {
            Class cls = Class.forName(classname);

            readAnnotation(cls.getDeclaredConstructors());
            readAnnotation(cls.getDeclaredMethods());

        } catch (ClassNotFoundException ex) {
            System.err.println(classname + " ܂");
        }
    }

    public void readAnnotation(Constructor[] constructors) {
        for (Constructor constructor : constructors) {
            readAnnotation(constructor);
        }
    }

    public void readAnnotation(Method[] methods) {
        for (Method method : methods) {
            readAnnotation(method);
        }
    }

    private void readAnnotation(AnnotatedElement element) {
        Log log = element.getAnnotation(Log.class);
        System.out.print("[" + element + "] is ");
        if (log != null) {
            LogLevel level = log.value();
            System.out.println("annotated Log.\n    value: " + level);
        } else {
            System.out.println("not annotated.\n");
        }
    }

    
    public static void main(String[] args) {
        if (args.length == 0) {
            System.err.println("Usage:");
            System.err.println("  java LogReader [classname] [classname] ...");
        }

        LogReader reader = new LogReader();

        for (String classname : args) {
            reader.readAnnotation(classname);
        }
    }
}
